@@ -1,6 +1,6 @@
 package Crypt::Bcrypt::Easy;
 {
-  $Crypt::Bcrypt::Easy::VERSION = '2.000003';
+  $Crypt::Bcrypt::Easy::VERSION = '2.001000';
 }
 use Carp;
 use strictures 1;
@@ -82,8 +82,8 @@ Crypt::Bcrypt::Easy - Simple interface to bcrypted passwords
   }
 
   # Generate passwords using a different default workcost:
-  my $bcrypt  = bcrypt( cost => 10 );
-  my $crypted = $bcrypt->crypt( $plain );
+  my $bc = bcrypt( cost => 10 );
+  my $crypted = $bc->crypt( $plain );
 
 =head1 DESCRIPTION
 
